
> Contact this for trial : @watefukk

command new-install
```
source <(curl -sL https://raw.githubusercontent.com/mabotsss/mav2/main/v2ray.sh)
```
uninstall
```
source <(curl -sL https://raw.githubusercontent.com/mabotsss/mav2/main/v2ray.sh) --remove
```
